# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.greenplum.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.greenplum.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.greenplum.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_config__pb2
from yandex.cloud.mdb.greenplum.v1 import host_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_host__pb2
from yandex.cloud.mdb.greenplum.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.greenplum.v1 import pxf_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_pxf__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/greenplum/v1/cluster_service.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a*yandex/cloud/mdb/greenplum/v1/backup.proto\x1a+yandex/cloud/mdb/greenplum/v1/cluster.proto\x1a*yandex/cloud/mdb/greenplum/v1/config.proto\x1a(yandex/cloud/mdb/greenplum/v1/host.proto\x1a/yandex/cloud/mdb/greenplum/v1/maintenance.proto\x1a\'yandex/cloud/mdb/greenplum/v1/pxf.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"i\n\x14ListClustersResponse\x12\x38\n\x08\x63lusters\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xec\t\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.mdb.greenplum.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12M\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x32.yandex.cloud.mdb.greenplum.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12>\n\x06\x63onfig\x18\x06 \x01(\x0b\x32..yandex.cloud.mdb.greenplum.v1.GreenplumConfig\x12P\n\rmaster_config\x18\x07 \x01(\x0b\x32\x39.yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfigSpec\x12R\n\x0esegment_config\x18\x08 \x01(\x0b\x32:.yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfigSpec\x12\x19\n\x11master_host_count\x18\t \x01(\x03\x12\x17\n\x0fsegment_in_host\x18\n \x01(\x03\x12\x1a\n\x12segment_host_count\x18\x0b \x01(\x03\x12\x17\n\tuser_name\x18\x0c \x01(\tB\x04\xe8\xc7\x31\x01\x12$\n\ruser_password\x18\r \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12 \n\nnetwork_id\x18\x0e \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0f \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x11 \x03(\t\x12L\n\x12maintenance_window\x18\x13 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.MaintenanceWindow\x12>\n\x0b\x63onfig_spec\x18\x14 \x01(\x0b\x32).yandex.cloud.mdb.greenplum.v1.ConfigSpec\x12\x42\n\rcloud_storage\x18\x15 \x01(\x0b\x32+.yandex.cloud.mdb.greenplum.v1.CloudStorage\x12\x1d\n\x15master_host_group_ids\x18\x16 \x03(\t\x12\x1e\n\x16segment_host_group_ids\x18\x17 \x03(\t\x12\x1a\n\x12service_account_id\x18\x18 \x01(\t\x12=\n\x07logging\x18\x19 \x01(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.LoggingConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x12\x10\x13\"\x91\x06\n\nConfigSpec\x12i\n\x15greenplum_config_6_17\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17H\x00R\x14greenplumConfig_6_17\x12i\n\x15greenplum_config_6_19\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19H\x00R\x14greenplumConfig_6_19\x12i\n\x15greenplum_config_6_21\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_21H\x00R\x14greenplumConfig_6_21\x12i\n\x15greenplum_config_6_22\x18\x05 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_22H\x00R\x14greenplumConfig_6_22\x12`\n\x12greenplum_config_6\x18\t \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6H\x00R\x11greenplumConfig_6\x12\x43\n\x04pool\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\x12X\n\x15\x62\x61\x63kground_activities\x18\x06 \x01(\x0b\x32\x39.yandex.cloud.mdb.greenplum.v1.BackgroundActivitiesConfig\x12<\n\npxf_config\x18\x08 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigB\x12\n\x10greenplum_configJ\x04\x08\x07\x10\x08\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x8d\x08\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.mdb.greenplum.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12(\n\x04name\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12>\n\x06\x63onfig\x18\x06 \x01(\x0b\x32..yandex.cloud.mdb.greenplum.v1.GreenplumConfig\x12P\n\rmaster_config\x18\x07 \x01(\x0b\x32\x39.yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfigSpec\x12R\n\x0esegment_config\x18\x08 \x01(\x0b\x32:.yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfigSpec\x12$\n\ruser_password\x18\r \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12\x1c\n\nnetwork_id\x18\x0e \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12L\n\x12maintenance_window\x18\x0f \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.MaintenanceWindow\x12\x1a\n\x12security_group_ids\x18\x11 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x12 \x01(\x08\x12>\n\x0b\x63onfig_spec\x18\x13 \x01(\x0b\x32).yandex.cloud.mdb.greenplum.v1.ConfigSpec\x12\x42\n\rcloud_storage\x18\x14 \x01(\x0b\x32+.yandex.cloud.mdb.greenplum.v1.CloudStorage\x12\x1a\n\x12service_account_id\x18\x15 \x01(\t\x12=\n\x07logging\x18\x16 \x01(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.LoggingConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x10\x10\x11J\x04\x08\t\x10\r\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"-\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xcb\x01\n\rExpandRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12segment_host_count\x18\x02 \x01(\x03\x12#\n\x1b\x61\x64\x64_segments_per_host_count\x18\x03 \x01(\x03\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x10\n\x08parallel\x18\x05 \x01(\x03\x12\x15\n\rclose_cluster\x18\x06 \x01(\x08\x12\x1c\n\x14\x64\x65lay_redistribution\x18\x07 \x01(\x08\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"\xce\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12i\n\x0freschedule_type\x18\x02 \x01(\x0e\x32J.yandex.cloud.mdb.greenplum.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"r\n\x1dRescheduleMaintenanceMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x37\n\rdelayed_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x18ListClusterHostsResponse\x12\x32\n\x05hosts\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.greenplum.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Y\n\x1aMasterSubclusterConfigSpec\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"Z\n\x1bSegmentSubclusterConfigSpec\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"j\n\x17ListClusterLogsResponse\x12\x36\n\x04logs\x18\x01 \x03(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb2\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\x07message\x18\x02 \x03(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe5\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12W\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x41.yandex.cloud.mdb.greenplum.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x08 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\t \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tGREENPLUM\x10\x01\x12\x14\n\x10GREENPLUM_POOLER\x10\x02\x12\x11\n\rGREENPLUM_PXF\x10\x03\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"f\n\x0fStreamLogRecord\x12\x38\n\x06record\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\xac\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12Y\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x43.yandex.cloud.mdb.greenplum.v1.StreamClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tGREENPLUM\x10\x01\x12\x14\n\x10GREENPLUM_POOLER\x10\x02\x12\x11\n\rGREENPLUM_PXF\x10\x03\"m\n\x1aListClusterBackupsResponse\x12\x36\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32%.yandex.cloud.mdb.greenplum.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\">\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xf4\x08\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x04time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x03 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x05 \x03(\x0b\x32@.yandex.cloud.mdb.greenplum.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12M\n\x0b\x65nvironment\x18\x06 \x01(\x0e\x32\x32.yandex.cloud.mdb.greenplum.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x45\n\x06\x63onfig\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumRestoreConfig\x12\x42\n\x10master_resources\x18\x08 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12\x43\n\x11segment_resources\x18\t \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\r \x03(\t\x12\x1a\n\x12placement_group_id\x18\x0e \x01(\t\x12L\n\x12maintenance_window\x18\x0f \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.MaintenanceWindow\x12\x1a\n\x12segment_host_count\x18\x11 \x01(\x03\x12\x17\n\x0fsegment_in_host\x18\x12 \x01(\x03\x12R\n\x0crestore_only\x18\x13 \x03(\tB<\xf2\xc7\x31\'[a-zA-Z0-9\\*_]*(\\/[a-zA-Z0-9\\*_]*){0,2}\x82\xc8\x31\x04<=50\x8a\xc8\x31\x05<=256\x12\x1d\n\x15master_host_group_ids\x18\x14 \x03(\t\x12\x1e\n\x16segment_host_group_ids\x18\x15 \x03(\t\x12\x1a\n\x12service_account_id\x18\x18 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x16\x10\x17J\x04\x08\x17\x10\x18\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t2\xfa\x1a\n\x0e\x43lusterService\x12\x94\x01\n\x03Get\x12\x30.yandex.cloud.mdb.greenplum.v1.GetClusterRequest\x1a&.yandex.cloud.mdb.greenplum.v1.Cluster\"3\x82\xd3\xe4\x93\x02-\x12+/managed-greenplum/v1/clusters/{cluster_id}\x12\x97\x01\n\x04List\x12\x32.yandex.cloud.mdb.greenplum.v1.ListClustersRequest\x1a\x33.yandex.cloud.mdb.greenplum.v1.ListClustersResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/managed-greenplum/v1/clusters\x12\xaf\x01\n\x06\x43reate\x12\x33.yandex.cloud.mdb.greenplum.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02#\"\x1e/managed-greenplum/v1/clusters:\x01*\x12\xbc\x01\n\x06Update\x12\x33.yandex.cloud.mdb.greenplum.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\x32+/managed-greenplum/v1/clusters/{cluster_id}:\x01*\x12\xbe\x01\n\x06\x45xpand\x12,.yandex.cloud.mdb.greenplum.v1.ExpandRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*\"\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x37\"2/managed-greenplum/v1/clusters/{cluster_id}/expand:\x01*\x12\xc7\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.mdb.greenplum.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02-*+/managed-greenplum/v1/clusters/{cluster_id}\x12\xbc\x01\n\x05Start\x12\x32.yandex.cloud.mdb.greenplum.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"1/managed-greenplum/v1/clusters/{cluster_id}:start\x12\xb8\x01\n\x04Stop\x12\x31.yandex.cloud.mdb.greenplum.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x32\"0/managed-greenplum/v1/clusters/{cluster_id}:stop\x12\xbb\x01\n\x04Move\x12\x31.yandex.cloud.mdb.greenplum.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x35\"0/managed-greenplum/v1/clusters/{cluster_id}:move:\x01*\x12\xf1\x01\n\x15RescheduleMaintenance\x12;.yandex.cloud.mdb.greenplum.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x46\"A/managed-greenplum/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xcb\x01\n\x0eListOperations\x12;.yandex.cloud.mdb.greenplum.v1.ListClusterOperationsRequest\x1a<.yandex.cloud.mdb.greenplum.v1.ListClusterOperationsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/managed-greenplum/v1/clusters/{cluster_id}/operations\x12\xc4\x01\n\x0fListMasterHosts\x12\x36.yandex.cloud.mdb.greenplum.v1.ListClusterHostsRequest\x1a\x37.yandex.cloud.mdb.greenplum.v1.ListClusterHostsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-greenplum/v1/clusters/{cluster_id}/master-hosts\x12\xc6\x01\n\x10ListSegmentHosts\x12\x36.yandex.cloud.mdb.greenplum.v1.ListClusterHostsRequest\x1a\x37.yandex.cloud.mdb.greenplum.v1.ListClusterHostsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/managed-greenplum/v1/clusters/{cluster_id}/segment-hosts\x12\xb3\x01\n\x08ListLogs\x12\x35.yandex.cloud.mdb.greenplum.v1.ListClusterLogsRequest\x1a\x36.yandex.cloud.mdb.greenplum.v1.ListClusterLogsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/managed-greenplum/v1/clusters/{cluster_id}:logs\x12\xb8\x01\n\nStreamLogs\x12\x37.yandex.cloud.mdb.greenplum.v1.StreamClusterLogsRequest\x1a..yandex.cloud.mdb.greenplum.v1.StreamLogRecord\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-greenplum/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xbf\x01\n\x0bListBackups\x12\x38.yandex.cloud.mdb.greenplum.v1.ListClusterBackupsRequest\x1a\x39.yandex.cloud.mdb.greenplum.v1.ListClusterBackupsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/managed-greenplum/v1/clusters/{cluster_id}/backups\x12\xc0\x01\n\x06\x42\x61\x63kup\x12\x33.yandex.cloud.mdb.greenplum.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x34\"2/managed-greenplum/v1/clusters/{cluster_id}:backup\x12\xba\x01\n\x07Restore\x12\x34.yandex.cloud.mdb.greenplum.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02+\"&/managed-greenplum/v1/clusters:restore:\x01*Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_password']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['user_password']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['user_password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_EXPANDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_EXPANDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _globals['_RESCHEDULEMAINTENANCEMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _globals['_RESCHEDULEMAINTENANCEMETADATA'].fields_by_name['delayed_until']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEMETADATA'].fields_by_name['delayed_until']._serialized_options = b'\350\3071\001'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LOGRECORD_MESSAGEENTRY']._loaded_options = None
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['restore_only']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['restore_only']._serialized_options = b'\362\3071\'[a-zA-Z0-9\\*_]*(\\/[a-zA-Z0-9\\*_]*){0,2}\202\3101\004<=50\212\3101\005<=256'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002-\022+/managed-greenplum/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002 \022\036/managed-greenplum/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002#\"\036/managed-greenplum/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00202+/managed-greenplum/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Expand']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Expand']._serialized_options = b'\262\322*\"\n\027AddClusterHostsMetadata\022\007Cluster\202\323\344\223\0027\"2/managed-greenplum/v1/clusters/{cluster_id}/expand:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002-*+/managed-greenplum/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0023\"1/managed-greenplum/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0022\"0/managed-greenplum/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0025\"0/managed-greenplum/v1/clusters/{cluster_id}:move:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002F\"A/managed-greenplum/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0028\0226/managed-greenplum/v1/clusters/{cluster_id}/operations'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListMasterHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListMasterHosts']._serialized_options = b'\202\323\344\223\002:\0228/managed-greenplum/v1/clusters/{cluster_id}/master-hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListSegmentHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListSegmentHosts']._serialized_options = b'\202\323\344\223\002;\0229/managed-greenplum/v1/clusters/{cluster_id}/segment-hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\0022\0220/managed-greenplum/v1/clusters/{cluster_id}:logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\0029\0227/managed-greenplum/v1/clusters/{cluster_id}:stream_logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0025\0223/managed-greenplum/v1/clusters/{cluster_id}/backups'
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0024\"2/managed-greenplum/v1/clusters/{cluster_id}:backup'
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002+\"&/managed-greenplum/v1/clusters:restore:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=553
  _globals['_GETCLUSTERREQUEST']._serialized_end=606
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=609
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=753
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=755
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=860
  _globals['_CREATECLUSTERREQUEST']._serialized_start=863
  _globals['_CREATECLUSTERREQUEST']._serialized_end=2123
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2072
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2117
  _globals['_CONFIGSPEC']._serialized_start=2126
  _globals['_CONFIGSPEC']._serialized_end=2911
  _globals['_CREATECLUSTERMETADATA']._serialized_start=2913
  _globals['_CREATECLUSTERMETADATA']._serialized_end=2956
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2959
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=3996
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2072
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2117
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=3998
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=4041
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=4043
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=4088
  _globals['_EXPANDREQUEST']._serialized_start=4091
  _globals['_EXPANDREQUEST']._serialized_end=4294
  _globals['_DELETECLUSTERREQUEST']._serialized_start=4296
  _globals['_DELETECLUSTERREQUEST']._serialized_end=4352
  _globals['_DELETECLUSTERMETADATA']._serialized_start=4354
  _globals['_DELETECLUSTERMETADATA']._serialized_end=4397
  _globals['_STARTCLUSTERREQUEST']._serialized_start=4399
  _globals['_STARTCLUSTERREQUEST']._serialized_end=4454
  _globals['_STARTCLUSTERMETADATA']._serialized_start=4456
  _globals['_STARTCLUSTERMETADATA']._serialized_end=4498
  _globals['_STOPCLUSTERREQUEST']._serialized_start=4500
  _globals['_STOPCLUSTERREQUEST']._serialized_end=4554
  _globals['_STOPCLUSTERMETADATA']._serialized_start=4556
  _globals['_STOPCLUSTERMETADATA']._serialized_end=4597
  _globals['_MOVECLUSTERREQUEST']._serialized_start=4599
  _globals['_MOVECLUSTERREQUEST']._serialized_end=4698
  _globals['_MOVECLUSTERMETADATA']._serialized_start=4700
  _globals['_MOVECLUSTERMETADATA']._serialized_end=4798
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=4801
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=5135
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=5025
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=5135
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=5137
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=5251
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=5253
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=5379
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=5381
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=5492
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=5494
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=5615
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=5617
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=5720
  _globals['_MASTERSUBCLUSTERCONFIGSPEC']._serialized_start=5722
  _globals['_MASTERSUBCLUSTERCONFIGSPEC']._serialized_end=5811
  _globals['_SEGMENTSUBCLUSTERCONFIGSPEC']._serialized_start=5813
  _globals['_SEGMENTSUBCLUSTERCONFIGSPEC']._serialized_end=5903
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=5905
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=6011
  _globals['_LOGRECORD']._serialized_start=6014
  _globals['_LOGRECORD']._serialized_end=6192
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=6146
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=6192
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=6195
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=6680
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=6581
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=6680
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=6682
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=6805
  _globals['_STREAMLOGRECORD']._serialized_start=6807
  _globals['_STREAMLOGRECORD']._serialized_end=6909
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=6912
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=7340
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=6581
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=6680
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=7342
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=7451
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=7453
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=7509
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=7511
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=7573
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=7576
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=8716
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=2072
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=2117
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=8718
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=8781
  _globals['_CLUSTERSERVICE']._serialized_start=8784
  _globals['_CLUSTERSERVICE']._serialized_end=12234
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.maintenance.v2.common_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class MaintenanceServiceStub:
    """A set of methods for managing maintenances in a service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.maintenance.v2.common_pb2.ListMaintenancesRequest,
        yandex.cloud.maintenance.v2.common_pb2.ListMaintenancesResponse,
    ]
    """Lists maintenances by conditions, specified in request."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.maintenance.v2.common_pb2.GetMaintenanceRequest,
        yandex.cloud.maintenance.v2.common_pb2.Maintenance,
    ]
    """Retrieves the specific Maintenance by ID."""

    Reschedule: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.maintenance.v2.common_pb2.RescheduleMaintenanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Allows user to reschedule Maintenance to another date and time."""

class MaintenanceServiceAsyncStub:
    """A set of methods for managing maintenances in a service."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.maintenance.v2.common_pb2.ListMaintenancesRequest,
        yandex.cloud.maintenance.v2.common_pb2.ListMaintenancesResponse,
    ]
    """Lists maintenances by conditions, specified in request."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.maintenance.v2.common_pb2.GetMaintenanceRequest,
        yandex.cloud.maintenance.v2.common_pb2.Maintenance,
    ]
    """Retrieves the specific Maintenance by ID."""

    Reschedule: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.maintenance.v2.common_pb2.RescheduleMaintenanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Allows user to reschedule Maintenance to another date and time."""

class MaintenanceServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing maintenances in a service."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.maintenance.v2.common_pb2.ListMaintenancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.maintenance.v2.common_pb2.ListMaintenancesResponse, collections.abc.Awaitable[yandex.cloud.maintenance.v2.common_pb2.ListMaintenancesResponse]]:
        """Lists maintenances by conditions, specified in request."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.maintenance.v2.common_pb2.GetMaintenanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.maintenance.v2.common_pb2.Maintenance, collections.abc.Awaitable[yandex.cloud.maintenance.v2.common_pb2.Maintenance]]:
        """Retrieves the specific Maintenance by ID."""

    @abc.abstractmethod
    def Reschedule(
        self,
        request: yandex.cloud.maintenance.v2.common_pb2.RescheduleMaintenanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Allows user to reschedule Maintenance to another date and time."""

def add_MaintenanceServiceServicer_to_server(servicer: MaintenanceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/searchindex/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/searchindex/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/ai/assistants/v1/searchindex/common.proto\x12)yandex.cloud.ai.assistants.v1.searchindex\x1a\x1egoogle/protobuf/wrappers.proto\"U\n\x16StaticChunkingStrategy\x12\x1d\n\x15max_chunk_size_tokens\x18\x01 \x01(\x03\x12\x1c\n\x14\x63hunk_overlap_tokens\x18\x02 \x01(\x03\"|\n\x10\x43hunkingStrategy\x12\\\n\x0fstatic_strategy\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.ai.assistants.v1.searchindex.StaticChunkingStrategyH\x00\x42\n\n\x08Strategy\"\x9c\x02\n\x17MeanCombinationStrategy\x12}\n\x19mean_evaluation_technique\x18\x01 \x01(\x0e\x32Z.yandex.cloud.ai.assistants.v1.searchindex.MeanCombinationStrategy.MeanEvaluationTechnique\x12\x0f\n\x07weights\x18\x02 \x03(\x01\"q\n\x17MeanEvaluationTechnique\x12)\n%MEAN_EVALUATION_TECHNIQUE_UNSPECIFIED\x10\x00\x12\x0e\n\nARITHMETIC\x10\x01\x12\r\n\tGEOMETRIC\x10\x02\x12\x0c\n\x08HARMONIC\x10\x03\"Q\n\'ReciprocalRankFusionCombinationStrategy\x12&\n\x01k\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xf0\x01\n\x13\x43ombinationStrategy\x12^\n\x10mean_combination\x18\x01 \x01(\x0b\x32\x42.yandex.cloud.ai.assistants.v1.searchindex.MeanCombinationStrategyH\x00\x12m\n\x0frrf_combination\x18\x02 \x01(\x0b\x32R.yandex.cloud.ai.assistants.v1.searchindex.ReciprocalRankFusionCombinationStrategyH\x00\x42\n\n\x08Strategy\"n\n\x0eNgramTokenizer\x12-\n\x08min_gram\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08max_gram\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x13\n\x11StandardTokenizer\"\x12\n\x10StandardAnalyzer\"\x16\n\x14YandexLemmerAnalyzer*T\n\x15NormalizationStrategy\x12&\n\"NORMALIZATION_STRATEGY_UNSPECIFIED\x10\x00\x12\x0b\n\x07MIN_MAX\x10\x01\x12\x06\n\x02L2\x10\x02\x42\x8a\x01\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.searchindex.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindex'
  _globals['_NORMALIZATIONSTRATEGY']._serialized_start=1136
  _globals['_NORMALIZATIONSTRATEGY']._serialized_end=1220
  _globals['_STATICCHUNKINGSTRATEGY']._serialized_start=133
  _globals['_STATICCHUNKINGSTRATEGY']._serialized_end=218
  _globals['_CHUNKINGSTRATEGY']._serialized_start=220
  _globals['_CHUNKINGSTRATEGY']._serialized_end=344
  _globals['_MEANCOMBINATIONSTRATEGY']._serialized_start=347
  _globals['_MEANCOMBINATIONSTRATEGY']._serialized_end=631
  _globals['_MEANCOMBINATIONSTRATEGY_MEANEVALUATIONTECHNIQUE']._serialized_start=518
  _globals['_MEANCOMBINATIONSTRATEGY_MEANEVALUATIONTECHNIQUE']._serialized_end=631
  _globals['_RECIPROCALRANKFUSIONCOMBINATIONSTRATEGY']._serialized_start=633
  _globals['_RECIPROCALRANKFUSIONCOMBINATIONSTRATEGY']._serialized_end=714
  _globals['_COMBINATIONSTRATEGY']._serialized_start=717
  _globals['_COMBINATIONSTRATEGY']._serialized_end=957
  _globals['_NGRAMTOKENIZER']._serialized_start=959
  _globals['_NGRAMTOKENIZER']._serialized_end=1069
  _globals['_STANDARDTOKENIZER']._serialized_start=1071
  _globals['_STANDARDTOKENIZER']._serialized_end=1090
  _globals['_STANDARDANALYZER']._serialized_start=1092
  _globals['_STANDARDANALYZER']._serialized_end=1110
  _globals['_YANDEXLEMMERANALYZER']._serialized_start=1112
  _globals['_YANDEXLEMMERANALYZER']._serialized_end=1134
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.instance_pb2
import yandex.cloud.compute.v1.instance_service_pb2
import yandex.cloud.compute.v1.reserved_instance_pool_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool resource to return.
    To get the reserved instance pool ID, use a [ReservedInstancePoolService.List] request.
    """
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___GetReservedInstancePoolRequest = GetReservedInstancePoolRequest

@typing.final
class ListReservedInstancePoolsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the Folder to list reserved instance pools in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListReservedInstancePoolsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListReservedInstancePoolsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListReservedInstancePoolsRequest = ListReservedInstancePoolsRequest

@typing.final
class ListReservedInstancePoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOLS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListReservedInstancePoolsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListReservedInstancePoolsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def reserved_instance_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool]:
        """List of reserved instance pool resources."""

    def __init__(
        self,
        *,
        reserved_instance_pools: collections.abc.Iterable[yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "reserved_instance_pools", b"reserved_instance_pools"]) -> None: ...

global___ListReservedInstancePoolsResponse = ListReservedInstancePoolsResponse

@typing.final
class CreateReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    PLATFORM_ID_FIELD_NUMBER: builtins.int
    RESOURCES_SPEC_FIELD_NUMBER: builtins.int
    GPU_SETTINGS_FIELD_NUMBER: builtins.int
    BOOT_DISK_SPEC_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ALLOW_OVERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the reserved instance pool."""
    description: builtins.str
    """Description of the reserved instance pool."""
    zone_id: builtins.str
    """ID of the availability zone where the reserved instance pool resides.
    To get a list of available zones, use the [yandex.cloud.compute.v1.ZoneService.List] request
    """
    folder_id: builtins.str
    """ID of the folder to create the reserved instance pool in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    platform_id: builtins.str
    """ID of the hardware platform configuration for the reserved instance pool.
    This field affects the available values in [resources_spec] field.

    For more information, see [Platforms](/docs/compute/concepts/vm-platforms).
    """
    size: builtins.int
    """Desired size of the pool (number of slots for instances in this pool)."""
    allow_oversubscription: builtins.bool
    """Allows the pool to contain more linked instances than the number of available slots (size without pending or unavailable slots).
    While running instances are still limited by available slots, stopped instances can exceed this limit.
    Warning: When this option is enabled, attempting to start more instances than the number of available slots will result in a "Not Enough Resources" error.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def resources_spec(self) -> yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec:
        """Computing resources of the reserved instance pool instances, such as the amount of memory and number of cores.
        To get a list of available values, see [Levels of core performance](/docs/compute/concepts/performance-levels).
        """

    @property
    def gpu_settings(self) -> yandex.cloud.compute.v1.instance_pb2.GpuSettings:
        """GPU settings."""

    @property
    def boot_disk_spec(self) -> yandex.cloud.compute.v1.reserved_instance_pool_pb2.BootDiskSpec:
        """Spec is used to determine which License IDs should be allowed for instances created in the pool."""

    @property
    def network_settings(self) -> yandex.cloud.compute.v1.instance_pb2.NetworkSettings:
        """Network settings."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        platform_id: builtins.str = ...,
        resources_spec: yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec | None = ...,
        gpu_settings: yandex.cloud.compute.v1.instance_pb2.GpuSettings | None = ...,
        boot_disk_spec: yandex.cloud.compute.v1.reserved_instance_pool_pb2.BootDiskSpec | None = ...,
        network_settings: yandex.cloud.compute.v1.instance_pb2.NetworkSettings | None = ...,
        size: builtins.int = ...,
        allow_oversubscription: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["boot_disk_spec", b"boot_disk_spec", "gpu_settings", b"gpu_settings", "network_settings", b"network_settings", "resources_spec", b"resources_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_oversubscription", b"allow_oversubscription", "boot_disk_spec", b"boot_disk_spec", "description", b"description", "folder_id", b"folder_id", "gpu_settings", b"gpu_settings", "labels", b"labels", "name", b"name", "network_settings", b"network_settings", "platform_id", b"platform_id", "resources_spec", b"resources_spec", "size", b"size", "zone_id", b"zone_id"]) -> None: ...

global___CreateReservedInstancePoolRequest = CreateReservedInstancePoolRequest

@typing.final
class CreateReservedInstancePoolMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool that is being created."""
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___CreateReservedInstancePoolMetadata = CreateReservedInstancePoolMetadata

@typing.final
class UpdateReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ALLOW_OVERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    ALLOW_PENDING_SLOTS_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool to update.
    To get the reserved instance pool ID, use a [ReservedInstancePoolService.List] request.
    """
    name: builtins.str
    """New name for the reserved instance pool."""
    description: builtins.str
    """Description of the reserved instance pool."""
    size: builtins.int
    """Desired size of the pool."""
    allow_oversubscription: builtins.bool
    """Allows the pool to contain more linked instances than the number of available slots (size without pending or unavailable slots).
    While running instances are still limited by available slots, stopped instances can exceed this limit.
    Warning: When this option is enabled, attempting to start more instances than the number of available slots will result in a "Not Enough Resources" error.
    """
    allow_pending_slots: builtins.bool
    """This field affects only the current request and allows size-increasing operation to complete successfully even when there are not enough resources.
    In such cases, some of the new pool slots become "pending", meaning they cannot be used until resources become available.
    Pending slots automatically convert to normal slots when sufficient resources are available.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the reserved instance pool should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        size: builtins.int = ...,
        allow_oversubscription: builtins.bool = ...,
        allow_pending_slots: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_oversubscription", b"allow_oversubscription", "allow_pending_slots", b"allow_pending_slots", "description", b"description", "labels", b"labels", "name", b"name", "reserved_instance_pool_id", b"reserved_instance_pool_id", "size", b"size", "update_mask", b"update_mask"]) -> None: ...

global___UpdateReservedInstancePoolRequest = UpdateReservedInstancePoolRequest

@typing.final
class UpdateReservedInstancePoolMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool that is being updated."""
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___UpdateReservedInstancePoolMetadata = UpdateReservedInstancePoolMetadata

@typing.final
class DeleteReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool to delete.
    To get the reserved instance pool ID, use a [ReservedInstancePoolService.List] request.
    """
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___DeleteReservedInstancePoolRequest = DeleteReservedInstancePoolRequest

@typing.final
class DeleteReservedInstancePoolMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool that is being deleted."""
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___DeleteReservedInstancePoolMetadata = DeleteReservedInstancePoolMetadata

@typing.final
class DeleteReservedInstancePoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteReservedInstancePoolResponse = DeleteReservedInstancePoolResponse

@typing.final
class ListReservedInstancePoolOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListReservedInstancePoolOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListReservedInstancePoolOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___ListReservedInstancePoolOperationsRequest = ListReservedInstancePoolOperationsRequest

@typing.final
class ListReservedInstancePoolOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListReservedInstancePoolOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListReservedInstancePoolOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified reserved instance pool."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListReservedInstancePoolOperationsResponse = ListReservedInstancePoolOperationsResponse

@typing.final
class ListReservedInstancePoolInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool to list instances for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListReservedInstancePoolInstancesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListReservedInstancePoolInstancesResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___ListReservedInstancePoolInstancesRequest = ListReservedInstancePoolInstancesRequest

@typing.final
class ListReservedInstancePoolInstancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListReservedInstancePoolInstancesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListReservedInstancePoolInstancesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instance_pb2.Instance]:
        """List of reserved instance pool instances."""

    def __init__(
        self,
        *,
        instances: collections.abc.Iterable[yandex.cloud.compute.v1.instance_pb2.Instance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instances", b"instances", "next_page_token", b"next_page_token"]) -> None: ...

global___ListReservedInstancePoolInstancesResponse = ListReservedInstancePoolInstancesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2
import yandex.cloud.trino.v1.access_control_pb2
import yandex.cloud.trino.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Health:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Health.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HEALTH_UNKNOWN: _Health.ValueType  # 0
    """Object is in unknown state (we have no data)"""
    ALIVE: _Health.ValueType  # 1
    """Object is alive and well (all hosts are alive)"""
    DEAD: _Health.ValueType  # 2
    """Object is inoperable (it cannot perform any of its essential functions)"""
    DEGRADED: _Health.ValueType  # 3
    """Object is partially alive (it can perform some of its essential functions)"""

class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...

HEALTH_UNKNOWN: Health.ValueType  # 0
"""Object is in unknown state (we have no data)"""
ALIVE: Health.ValueType  # 1
"""Object is alive and well (all hosts are alive)"""
DEAD: Health.ValueType  # 2
"""Object is inoperable (it cannot perform any of its essential functions)"""
DEGRADED: Health.ValueType  # 3
"""Object is partially alive (it can perform some of its essential functions)"""
global___Health = Health

@typing.final
class Cluster(google.protobuf.message.Message):
    """Trino cluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        STOPPING: Cluster._Status.ValueType  # 4
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 5
        """Cluster is stopped."""
        STARTING: Cluster._Status.ValueType  # 6
        """Cluster is starting."""
        UPDATING: Cluster._Status.ValueType  # 7
        """Cluster is being updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    STOPPING: Cluster.Status.ValueType  # 4
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 5
    """Cluster is stopped."""
    STARTING: Cluster.Status.ValueType  # 6
    """Cluster is starting."""
    UPDATING: Cluster.Status.ValueType  # 7
    """Cluster is being updated."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    TRINO_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    COORDINATOR_URL_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique ID of the Trino cluster.
    This ID is assigned by Cloud in the process of creating a Trino cluster.
    """
    folder_id: builtins.str
    """ID of the folder that the Trino cluster belongs to."""
    name: builtins.str
    """Name of the Trino cluster.
    The name is unique within the folder. 1-64 characters long.
    """
    description: builtins.str
    """Description of the Trino cluster. 0-256 characters long."""
    health: global___Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Cluster status."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster."""
    service_account_id: builtins.str
    """Service account used to access Cloud resources."""
    coordinator_url: builtins.str
    """Address of Trino Coordinator."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the Trino cluster was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Monitoring systems relevant to the Trino cluster."""

    @property
    def trino(self) -> global___TrinoConfig:
        """Configuration of the Trino cluster."""

    @property
    def network(self) -> global___NetworkConfig:
        """Network related configuration options."""

    @property
    def logging(self) -> global___LoggingConfig:
        """Cloud logging configuration."""

    @property
    def maintenance_window(self) -> yandex.cloud.trino.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    @property
    def planned_operation(self) -> yandex.cloud.trino.v1.maintenance_pb2.MaintenanceOperation:
        """Maintenance operation planned at nearest maintenance_window."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        trino: global___TrinoConfig | None = ...,
        health: global___Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        network: global___NetworkConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        service_account_id: builtins.str = ...,
        logging: global___LoggingConfig | None = ...,
        coordinator_url: builtins.str = ...,
        maintenance_window: yandex.cloud.trino.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.trino.v1.maintenance_pb2.MaintenanceOperation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "logging", b"logging", "maintenance_window", b"maintenance_window", "network", b"network", "planned_operation", b"planned_operation", "trino", b"trino"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["coordinator_url", b"coordinator_url", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network", b"network", "planned_operation", b"planned_operation", "service_account_id", b"service_account_id", "status", b"status", "trino", b"trino"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Monitoring system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class LoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Logs generated by the Trino components are delivered to Cloud Logging."""
    folder_id: builtins.str
    """Logs should be written to default log group for specified folder."""
    log_group_id: builtins.str
    """Logs should be written to log group resolved by ID."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        folder_id: builtins.str = ...,
        log_group_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "enabled", b"enabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["folder_id", "log_group_id"] | None: ...

global___LoggingConfig = LoggingConfig

@typing.final
class NetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of VPC network subnets where instances of the cluster are attached."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    def __init__(
        self,
        *,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___NetworkConfig = NetworkConfig

@typing.final
class TrinoConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COORDINATOR_CONFIG_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    ACCESS_CONTROL_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of Trino."""
    @property
    def coordinator_config(self) -> global___CoordinatorConfig:
        """Configuration for the coordinator, specifying computational resources and other settings."""

    @property
    def worker_config(self) -> global___WorkerConfig:
        """Configuration for worker nodes, including scaling policy and computational resources."""

    @property
    def retry_policy(self) -> global___RetryPolicyConfig:
        """Configuration for retry policy, specifying the spooling storage destination and other settings."""

    @property
    def access_control(self) -> yandex.cloud.trino.v1.access_control_pb2.AccessControlConfig:
        """Configuration for access control, specifying the fine-grained rules of accesses."""

    def __init__(
        self,
        *,
        coordinator_config: global___CoordinatorConfig | None = ...,
        worker_config: global___WorkerConfig | None = ...,
        version: builtins.str = ...,
        retry_policy: global___RetryPolicyConfig | None = ...,
        access_control: yandex.cloud.trino.v1.access_control_pb2.AccessControlConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_control", b"access_control", "coordinator_config", b"coordinator_config", "retry_policy", b"retry_policy", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_control", b"access_control", "coordinator_config", b"coordinator_config", "retry_policy", b"retry_policy", "version", b"version", "worker_config", b"worker_config"]) -> None: ...

global___TrinoConfig = TrinoConfig

@typing.final
class CoordinatorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Configuration for computational resources assigned to the coordinator instance."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___CoordinatorConfig = CoordinatorConfig

@typing.final
class WorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class WorkerScalePolicy(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FIXED_SCALE_FIELD_NUMBER: builtins.int
        AUTO_SCALE_FIELD_NUMBER: builtins.int
        @property
        def fixed_scale(self) -> global___FixedScalePolicy:
            """A fixed scaling policy that specifies a fixed number of worker instances."""

        @property
        def auto_scale(self) -> global___AutoScalePolicy:
            """A scaling policy that dynamically adjusts the number of worker instances
            based on the cluster's workload. The system automatically increases or
            decreases the number of instances within the defined range.
            """

        def __init__(
            self,
            *,
            fixed_scale: global___FixedScalePolicy | None = ...,
            auto_scale: global___AutoScalePolicy | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["scale_type", b"scale_type"]) -> typing.Literal["fixed_scale", "auto_scale"] | None: ...

    RESOURCES_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Configuration for computational resources for worker instances."""

    @property
    def scale_policy(self) -> global___WorkerConfig.WorkerScalePolicy:
        """Configuration for scaling policy for worker instances."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
        scale_policy: global___WorkerConfig.WorkerScalePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources", "scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources", "scale_policy", b"scale_policy"]) -> None: ...

global___WorkerConfig = WorkerConfig

@typing.final
class RetryPolicyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RetryPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RetryPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RetryPolicyConfig._RetryPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RETRY_POLICY_UNSPECIFIED: RetryPolicyConfig._RetryPolicy.ValueType  # 0
        QUERY: RetryPolicyConfig._RetryPolicy.ValueType  # 1
        TASK: RetryPolicyConfig._RetryPolicy.ValueType  # 2

    class RetryPolicy(_RetryPolicy, metaclass=_RetryPolicyEnumTypeWrapper): ...
    RETRY_POLICY_UNSPECIFIED: RetryPolicyConfig.RetryPolicy.ValueType  # 0
    QUERY: RetryPolicyConfig.RetryPolicy.ValueType  # 1
    TASK: RetryPolicyConfig.RetryPolicy.ValueType  # 2

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    POLICY_FIELD_NUMBER: builtins.int
    EXCHANGE_MANAGER_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    policy: global___RetryPolicyConfig.RetryPolicy.ValueType
    """Retry policy level."""
    @property
    def exchange_manager(self) -> global___ExchangeManagerConfig:
        """Configuration for exchange manager."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        policy: global___RetryPolicyConfig.RetryPolicy.ValueType = ...,
        exchange_manager: global___ExchangeManagerConfig | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["exchange_manager", b"exchange_manager"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "exchange_manager", b"exchange_manager", "policy", b"policy"]) -> None: ...

global___RetryPolicyConfig = RetryPolicyConfig

@typing.final
class ExchangeManagerStorage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ServiceS3(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    SERVICE_S3_FIELD_NUMBER: builtins.int
    @property
    def service_s3(self) -> global___ExchangeManagerStorage.ServiceS3:
        """Use service side s3 bucket for exchange manager."""

    def __init__(
        self,
        *,
        service_s3: global___ExchangeManagerStorage.ServiceS3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["service_s3", b"service_s3", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["service_s3", b"service_s3", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["service_s3"] | None: ...

global___ExchangeManagerStorage = ExchangeManagerStorage

@typing.final
class ExchangeManagerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    STORAGE_FIELD_NUMBER: builtins.int
    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    @property
    def storage(self) -> global___ExchangeManagerStorage: ...
    def __init__(
        self,
        *,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        storage: global___ExchangeManagerStorage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["storage", b"storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "storage", b"storage"]) -> None: ...

global___ExchangeManagerConfig = ExchangeManagerConfig

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources allocated to a instance (e.g., CPU, memory, etc.)."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class FixedScalePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    """Specifies the number of worker instances."""
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count"]) -> None: ...

global___FixedScalePolicy = FixedScalePolicy

@typing.final
class AutoScalePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_COUNT_FIELD_NUMBER: builtins.int
    MAX_COUNT_FIELD_NUMBER: builtins.int
    min_count: builtins.int
    max_count: builtins.int
    def __init__(
        self,
        *,
        min_count: builtins.int = ...,
        max_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_count", b"max_count", "min_count", b"min_count"]) -> None: ...

global___AutoScalePolicy = AutoScalePolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/kafka.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/kafka.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/connectionmanager/v1/kafka.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a.yandex/cloud/connectionmanager/v1/common.proto\"\x95\x02\n\x11KafkaSaslSecurity\x12\x0c\n\x04user\x18\x01 \x01(\t\x12=\n\x08password\x18\x02 \x01(\x0b\x32+.yandex.cloud.connectionmanager.v1.Password\x12\\\n\x14supported_mechanisms\x18\x03 \x03(\x0e\x32>.yandex.cloud.connectionmanager.v1.KafkaSaslSecurity.Mechanism\"U\n\tMechanism\x12\x19\n\x15MECHANISM_UNSPECIFIED\x10\x00\x12\t\n\x05PLAIN\x10\x01\x12\x10\n\x0cSCRAM_SHA256\x10\x02\x12\x10\n\x0cSCRAM_SHA512\x10\x03\"\x89\x01\n\tKafkaAuth\x12\x44\n\x04sasl\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.KafkaSaslSecurityH\x00\x12*\n\x08\x64isabled\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\n\n\x08security\"\xcc\x02\n\x0cKafkaCluster\x12\x43\n\x05hosts\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.KafkaCluster.Host\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xb4\x01\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12K\n\x06health\x18\x03 \x01(\x0e\x32;.yandex.cloud.connectionmanager.v1.KafkaCluster.Host.Health\"C\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xab\x01\n\x0fKafkaConnection\x12@\n\x07\x63luster\x18\x01 \x01(\x0b\x32/.yandex.cloud.connectionmanager.v1.KafkaCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12:\n\x04\x61uth\x18\x03 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.KafkaAuthB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.kafka_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_KAFKASASLSECURITY']._serialized_start=162
  _globals['_KAFKASASLSECURITY']._serialized_end=439
  _globals['_KAFKASASLSECURITY_MECHANISM']._serialized_start=354
  _globals['_KAFKASASLSECURITY_MECHANISM']._serialized_end=439
  _globals['_KAFKAAUTH']._serialized_start=442
  _globals['_KAFKAAUTH']._serialized_end=579
  _globals['_KAFKACLUSTER']._serialized_start=582
  _globals['_KAFKACLUSTER']._serialized_end=914
  _globals['_KAFKACLUSTER_HOST']._serialized_start=734
  _globals['_KAFKACLUSTER_HOST']._serialized_end=914
  _globals['_KAFKACLUSTER_HOST_HEALTH']._serialized_start=847
  _globals['_KAFKACLUSTER_HOST_HEALTH']._serialized_end=914
  _globals['_KAFKACONNECTION']._serialized_start=917
  _globals['_KAFKACONNECTION']._serialized_end=1088
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.backup.v1.backup_pb2
import yandex.cloud.backup.v1.backup_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BackupServiceStub:
    """A set of methods for managing [backups](/docs/backup/concepts/backup)."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.ListBackupsRequest,
        yandex.cloud.backup.v1.backup_service_pb2.ListBackupsResponse,
    ]
    """List backups using filters."""

    ListArchives: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.ListArchivesRequest,
        yandex.cloud.backup.v1.backup_service_pb2.ListArchivesResponse,
    ]
    """List archives that holds backups for specified folder or
    specified [Compute Cloud instance](/docs/backup/concepts/vm-connection#os).
    """

    ListFiles: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.ListFilesRequest,
        yandex.cloud.backup.v1.backup_service_pb2.ListFilesResponse,
    ]
    """ListFiles of the backup."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.GetBackupRequest,
        yandex.cloud.backup.v1.backup_pb2.Backup,
    ]
    """Get backup by its id."""

    StartRecovery: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.StartRecoveryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start recovery process of specified backup to specific Compute Cloud instance.

    For details, see [Restoring a VM from a backup](/docs/backup/operations/backup-vm/recover).
    """

    StartFilesRecovery: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.StartFilesRecoveryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """StartFilesRecovery runs recovery process of selected files to specific Compute Cloud instance."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.DeleteBackupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific backup."""

    DeleteArchive: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.DeleteArchiveRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific archive."""

class BackupServiceAsyncStub:
    """A set of methods for managing [backups](/docs/backup/concepts/backup)."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.ListBackupsRequest,
        yandex.cloud.backup.v1.backup_service_pb2.ListBackupsResponse,
    ]
    """List backups using filters."""

    ListArchives: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.ListArchivesRequest,
        yandex.cloud.backup.v1.backup_service_pb2.ListArchivesResponse,
    ]
    """List archives that holds backups for specified folder or
    specified [Compute Cloud instance](/docs/backup/concepts/vm-connection#os).
    """

    ListFiles: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.ListFilesRequest,
        yandex.cloud.backup.v1.backup_service_pb2.ListFilesResponse,
    ]
    """ListFiles of the backup."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.GetBackupRequest,
        yandex.cloud.backup.v1.backup_pb2.Backup,
    ]
    """Get backup by its id."""

    StartRecovery: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.StartRecoveryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start recovery process of specified backup to specific Compute Cloud instance.

    For details, see [Restoring a VM from a backup](/docs/backup/operations/backup-vm/recover).
    """

    StartFilesRecovery: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.StartFilesRecoveryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """StartFilesRecovery runs recovery process of selected files to specific Compute Cloud instance."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.DeleteBackupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific backup."""

    DeleteArchive: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.backup_service_pb2.DeleteArchiveRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific archive."""

class BackupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing [backups](/docs/backup/concepts/backup)."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.ListBackupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.backup_service_pb2.ListBackupsResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.backup_service_pb2.ListBackupsResponse]]:
        """List backups using filters."""

    @abc.abstractmethod
    def ListArchives(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.ListArchivesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.backup_service_pb2.ListArchivesResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.backup_service_pb2.ListArchivesResponse]]:
        """List archives that holds backups for specified folder or
        specified [Compute Cloud instance](/docs/backup/concepts/vm-connection#os).
        """

    @abc.abstractmethod
    def ListFiles(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.ListFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.backup_service_pb2.ListFilesResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.backup_service_pb2.ListFilesResponse]]:
        """ListFiles of the backup."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.GetBackupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.backup_pb2.Backup, collections.abc.Awaitable[yandex.cloud.backup.v1.backup_pb2.Backup]]:
        """Get backup by its id."""

    @abc.abstractmethod
    def StartRecovery(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.StartRecoveryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Start recovery process of specified backup to specific Compute Cloud instance.

        For details, see [Restoring a VM from a backup](/docs/backup/operations/backup-vm/recover).
        """

    @abc.abstractmethod
    def StartFilesRecovery(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.StartFilesRecoveryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """StartFilesRecovery runs recovery process of selected files to specific Compute Cloud instance."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.DeleteBackupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete specific backup."""

    @abc.abstractmethod
    def DeleteArchive(
        self,
        request: yandex.cloud.backup.v1.backup_service_pb2.DeleteArchiveRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete specific archive."""

def add_BackupServiceServicer_to_server(servicer: BackupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AsymmetricEncryptionCryptoServiceStub:
    """Data plane for KMS symmetric cryptography operations

    Set of methods that perform asymmetric decryption.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Decrypt: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricDecryptRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricDecryptResponse,
    ]
    """Decrypts the given ciphertext with the specified key."""

    GetPublicKey: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricGetPublicKeyRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricGetPublicKeyResponse,
    ]
    """Gets value of public key."""

class AsymmetricEncryptionCryptoServiceAsyncStub:
    """Data plane for KMS symmetric cryptography operations

    Set of methods that perform asymmetric decryption.
    """

    Decrypt: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricDecryptRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricDecryptResponse,
    ]
    """Decrypts the given ciphertext with the specified key."""

    GetPublicKey: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricGetPublicKeyRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricGetPublicKeyResponse,
    ]
    """Gets value of public key."""

class AsymmetricEncryptionCryptoServiceServicer(metaclass=abc.ABCMeta):
    """Data plane for KMS symmetric cryptography operations

    Set of methods that perform asymmetric decryption.
    """

    @abc.abstractmethod
    def Decrypt(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricDecryptRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricDecryptResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricDecryptResponse]]:
        """Decrypts the given ciphertext with the specified key."""

    @abc.abstractmethod
    def GetPublicKey(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricGetPublicKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricGetPublicKeyResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2.AsymmetricGetPublicKeyResponse]]:
        """Gets value of public key."""

def add_AsymmetricEncryptionCryptoServiceServicer_to_server(servicer: AsymmetricEncryptionCryptoServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UserInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INN_FIELD_NUMBER: builtins.int
    KPP_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID, reserved field"""
    name: builtins.str
    """Name of legal person"""
    inn: builtins.str
    """INN of legal person"""
    kpp: builtins.str
    """KPP of legal person"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        inn: builtins.str = ...,
        kpp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "inn", b"inn", "kpp", b"kpp", "name", b"name"]) -> None: ...

global___UserInfo = UserInfo
